#
# spec file for package uhd
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           uhd
%define libname libuhd003
Version:        3.8.5
Release:        7.12
%define src_ver 003.008.005
%define img_ver 003.008.005
Summary:        The driver for USRP SDR boards
License:        GPL-3.0+
Group:          Hardware/Other
Url:            http://ettus-apps.sourcerepo.com/redmine/ettus/projects/uhd/wiki
Source0:        http://files.ettus.com/binaries/uhd_stable/uhd_%{src_ver}-release/uhd-%{version}.tar.gz
Source1:        http://files.ettus.com/binaries/images/uhd-images_%{img_ver}-release.tar.gz
Patch0:         arm-neon.patch
BuildRequires:  boost-devel >= 1.36
BuildRequires:  cmake >= 2.6
BuildRequires:  docutils
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  orc
BuildRequires:  pkg-config
BuildRequires:  python-cheetah >= 2.0.0
BuildRequires:  python-devel >= 2.6
BuildRequires:  udev
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       udev
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

%package     -n %{libname}
Summary:        The UHD driver
Group:          Hardware/Other
Requires:       %{name}-udev >= %{version}
# PRE script requires /usr/sbin/groupadd, that exist in "shadow" package
Requires(pre):  shadow

%description -n %{libname}
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

%package        udev
Summary:        UHD udev rules
Group:          Hardware/Other

%description    udev
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

This package contains udev rules for UHD.

%package        devel
Summary:        Development files for uhd
Group:          Development/Libraries/Other
Requires:       %{libname} = %{version}
Requires:       boost-devel
Recommends:     %{name}-doc

%description    devel
The UHD is the "Universal Software Radio Peripheral" hardware driver.
The goal of the UHD is to provide a host driver and API for current
and future Ettus Research products. Users will be able to use the
UHD driver standalone or with 3rd party applications.

This package contains all the necessary tools, examples and include
files for development with the UHD Driver.

%package        doc
Summary:        Documentation files for uhd
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
This package contains the documentation for the Universal Hardware Driver (UHD).

%package        firmware
Summary:        Firmware images for uhd
Group:          Hardware/Other
Requires:       %{libname} = %{version}
BuildArch:      noarch

%description    firmware
This package contains binary firmware images for the Universal Hardware Driver (UHD).

%prep
%setup -q 
%patch0 -p1

# remove buildtime from documentation
echo "HTML_TIMESTAMP         = NO" >> docs/Doxyfile.in

%build
touch ../README.md
%cmake
make VERBOSE=1 %{?_smp_mflags}

%check
# Disable tests due to failure of convert_test on openSUSE 13.1
#cd build
#make VERBOSE=1 test

%install
%cmake_install

# Fix udev rules and allow access only to users in usrp group
sed -i 's/BUS==/SUBSYSTEM==/;s/SYSFS{/ATTRS{/;s/MODE:="0666"/GROUP:="usrp", MODE:="0660"/' %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules
install -m 0644 -D %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules %{buildroot}%{_udevrulesdir}/10-usrp-uhd.rules
rm %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules

# Move documentation at the default docdir
mkdir -p  %{buildroot}%{_docdir}/uhd
mv %{buildroot}%{_datadir}/doc/uhd %{buildroot}%{_docdir}/
mv %{buildroot}%{_libdir}/uhd/utils/*[!.rules] %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/examples/* %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/tests/* %{buildroot}%{_bindir}

rm -rf %{buildroot}%{_libdir}/uhd/tests
rm -rf %{buildroot}%{_libdir}/uhd/examples

rm -rf %{buildroot}%{_docdir}/uhd/LICENSE
rm -rf %{buildroot}%{_docdir}/uhd/README.md

# two executable files are installed to /usr/share/uhd
mv %{buildroot}%{_libdir}/uhd/utils/query_gpsdo_sensors %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/utils/usrp_n2xx_simple_net_burner %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/utils/b2xx_fx3_utils %{buildroot}%{_bindir}
mv %{buildroot}%{_libdir}/uhd/utils/usrp_x3xx_fpga_burner %{buildroot}%{_bindir}

# extract firmware
mkdir -p %{buildroot}%{_datadir}/uhd
tar -xzvf %{SOURCE1} --transform="s,^uhd-images_%{img_ver}-release/share/uhd/,," --show-transformed-names -C %{buildroot}%{_datadir}/uhd

# find dupes
%fdupes -s %{buildroot}%{_bindir}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_datadir}/uhd

%pre -n %{libname}
getent group usrp >/dev/null || %{_sbindir}/groupadd -r usrp >/dev/null

%post -n %{libname}
/sbin/ldconfig

%postun -n %{libname}
/sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc LICENSE
%{_libdir}/*.so.*.*

%files udev
%defattr(-,root,root)
%{_udevrulesdir}/10-usrp-uhd.rules

%files devel
%defattr(-,root,root)
%dir %{_includedir}/uhd
%dir %{_datadir}/uhd
%exclude %{_datadir}/uhd/images
%{_includedir}/uhd/*
%{_bindir}/*
%{_libdir}/libuhd.so
%{_libdir}/libuhd.so.003
%{_libdir}/pkgconfig/uhd.pc
%{_libdir}/cmake/uhd
%{_mandir}/man1/*

%files firmware
%defattr(-,root,root)
%{_datadir}/uhd/images/

%files doc
%defattr(-,root,root)
%dir %{_docdir}/uhd
%{_docdir}/uhd/doxygen
#{_docdir}/uhd/manual

%changelog
* Thu Oct 27 2016 dl8fcl@t-online.de
- %%pre script requires /usr/sbin/groupadd from "shadow" package
  backport from current version in project hardware
* Tue Aug 18 2015 wk@ire.pw.edu.pl
- Update sources to version 3.8.5
* Wed Aug 12 2015 schwab@suse.de
- arm-neon.patch: don't use 32-bit arm code on 64-bit arm
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Add _constraints to set required memory to 3Gb
* Sat May 16 2015 wk@ire.pw.edu.pl
- Update sources to version 3.8.4
* Wed Feb 18 2015 wk@ire.pw.edu.pl
- Update sources to version 3.8.2
* Thu Jan 29 2015 wk@ire.pw.edu.pl
- Update to version 3.8.1
  * firmware images are from 3.8.2
* Thu Oct 23 2014 wk@ire.pw.edu.pl
- Update to version 3.7.3
  * firmware images are from 3.7.2
* Mon Sep  1 2014 wk@ire.pw.edu.pl
- Update to version 3.7.2
  * bugfix release
* Wed Aug 20 2014 dmitry_r@opensuse.org
- Cleanup spec file
- Remove OBS source service
- Use %%cmake macros
- Move udev rules to uhd-udev package according to shared library
  packaging policy
- Remove buildtime from documentation
* Wed Apr  2 2014 wk@ire.pw.edu.pl
- Update to version 3.7.0
* Thu Jan 30 2014 lnt-sysadmin@lists.lrz.de
- Changes to spec file:
  * Use full path when calling groupadd
* Wed Jan 29 2014 opensuse@dstoecker.de
- uhd-devel needs boost
* Sun Nov  3 2013 lnt-sysadmin@lists.lrz.de
- Update to version 3.5.4
- Changes to spec file:
  * Update udev paths for openSUSE 13.1 and ensure udev rules are
    updated when package is installed / updated / uninstalled.
  * Add %%check section (currently disabled due to failures in 13.1)
  * Find file dupes also in %%_bindir
* Fri Apr 12 2013 lnt-sysadmin@lists.lrz.de
- Update to version 3.5.2
- Added Ettus firmware images (version 3.5.2)
- Changes to spec file:
  * pass %%optflags to cmake according to
    http://en.opensuse.org/openSUSE:Build_system_recipes
  * fixed search for duplicate files
* Wed Nov  7 2012 wk@ire.pw.edu.pl
- updated to 3.5.0
- fixed some rpmlint warnings
* Tue Oct 23 2012 wk@ire.pw.edu.pl
- install udev rule (from Fedora)
* Sun Oct 21 2012 wk@ire.pw.edu.pl
- updated to 3.4.3
* Fri Jun 15 2012 surligas@csd.uoc.gr
- packaged libuhd version 3.4.2
